@@ -1,24 +1,18 @@
 package My::DynamicHTML;
 
-use Apache::RequestIO ();  # for puts()
+use Apache::RequestIO ();  # for $r->print
 use Apache::RequestRec (); # for $r->content_type
 
 use Apache::Const -compile => qw(OK);
 
+use strict;
+
 sub handler {
+
   my $r = shift;
 
   $r->content_type('text/html');
-  $r->puts(<<EOF);
-<html>
-<head>
-  <title></title>
-</head>
-<body>
-some inline HTML
-</body>
-</html>
-EOF
+  $r->print(q!<i    ><strong>&quot;This is a test&quot;</strong></i   >!);
 
   return Apache::OK;
 }
